@@ -148,7 +148,7 @@ static int dequote(char *inplace) {
   int v;
 
   p=q=inplace;
-  assert(*p++ = '"');
+  assert(*p=='"');  p++;
   while (*p && *p != '"') {
     if (*p != '\\') { *q++= *p++; continue; }
     switch (*++p) {
@@ -183,7 +183,7 @@ static int dequote(char *inplace) {
       }
     }
   }
-  assert(*p); assert(!*++p);
+  assert(*p); p++; assert(!*p);
   *q++= 0;
   return tokv_quotedstring;
 }
